import { GetObjectCommand, S3Client } from '@aws-sdk/client-s3';
import { execSync } from 'node:child_process';

const formatMemoryUsage = (data: number) => `${Math.round(data / 1024 / 1024 * 100) / 100} MB`;

export const memoryUsage = () => {
    const { rss, heapUsed, heapTotal, external } = process.memoryUsage();
    console.log({
        rss: `${formatMemoryUsage(rss)} -> Resident Set Size - total memory allocated for the process execution`,
        heapTotal: `${formatMemoryUsage(heapTotal)} -> total size of the allocated heap`,
        heapUsed: `${formatMemoryUsage(heapUsed)} -> actual memory used during the execution`,
        external: `${formatMemoryUsage(external)} -> V8 external memory`,
    });
};

console.log(execSync('npm ls @aws-sdk/client-s3').toString());

console.log('Starting...');
memoryUsage();

console.log('Instantiating client...');
const client = new S3Client();
memoryUsage();

console.log('Using client 100 times...');

console.log('Before:')
memoryUsage();
const get = new GetObjectCommand({
    Bucket: '',
    Key: ''
});

Array.from(Array(100)).forEach(async () => {
    try {
        await client.send(get);
    } catch (e) {
        // yolo
    }
})
console.log('After:')
memoryUsage();
